import{d as b,ez as g,eA as v,r as k,b as r,c as a,w as s,u as e,f as c,ew as n}from"./outputWidgets.903ef13f.js";import{S as h,L as w}from"./SmartConsole.051eedb1.js";import{a as x}from"./asyncComputed.c4e04ddf.js";import{H as B}from"./hooks.25569791.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.69262f1d.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.6502a11c.js";import{B as I}from"./BaseLayout.206b37c4.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.58470624.js";import{c as A}from"./index.33a83bfb.js";import{A as _,T as D}from"./TabPane.a0a5d077.js";import"./forms.faec79b9.js";import"./activeRecord.55ed0790.js";import"./pubsub.c9a1cd12.js";import"./dashes.b1fc78bb.js";import"./index.e5fe38b8.js";import"./jobs.04bac720.js";import"./workspaces.1ca64420.js";import"./url.08ed6687.js";import"./icons.c6b9d5b7.js";import"./Title.a0ce44ea.js";import"./index.d93d8aa2.js";import"./uuid.d60a69af.js";import"./ant-design.6476f34e.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.c1082ad9.js";import"./RunButton.vue_vue_type_script_setup_true_lang.cb1d0943.js";import"./index.e54403aa.js";import"./index.abf1ee4c.js";import"./CollapsePanel.51ba056d.js";import"./index.ff825c04.js";import"./index.7ad33f1e.js";import"./index.c70ecf50.js";import"./Form.49dc913d.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="eb5d6b7c-cac5-4998-aaf4-cdec4997be5d",i._sentryDebugIdIdentifier="sentry-dbid-eb5d6b7c-cac5-4998-aaf4-cdec4997be5d")}catch{}})();const ue=b({__name:"HookEditor",setup(i){const m=g(),u=v(),l=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(u.params.hookPath)),f=w.create();return(R,d)=>(r(),a(I,null,{navbar:s(()=>[e(t)?(r(),a(e(A),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:s(()=>[c(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:s(()=>[c(e(_),{key:"test",tab:"Test"}),c(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[c(H,{path:"hooks"}),o.value==="settings"?(r(),a(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:s(()=>[e(t)&&o.value==="test"?(r(),a(S,{key:0,ref_key:"tester",ref:l,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),a(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:s(()=>{var p;return[e(t)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=l.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{ue as default};
//# sourceMappingURL=HookEditor.e77b94fe.js.map
