import{x as o,a,b as i,c,g as p,h as d,_,i as u,T as l,j as f,P as h,C as m,M as y,s as b,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.903ef13f.js";import{u as k}from"./index.bc8c2490.js";import"./pubsub.c9a1cd12.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9706bee4-04fe-4412-b827-398d28ac2f60",e._sentryDebugIdIdentifier="sentry-dbid-9706bee4-04fe-4412-b827-398d28ac2f60")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.a85ffaca.js"),["assets/Player.a85ffaca.js","assets/index.e5fe38b8.js","assets/outputWidgets.903ef13f.js","assets/outputWidgets.e6401203.css","assets/uuid.d60a69af.js","assets/broker.a83b5551.js","assets/index.bc8c2490.js","assets/pubsub.c9a1cd12.js","assets/executeJs.16c242ef.js","assets/icons.c6b9d5b7.js","assets/CircularLoading.adfd7b04.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.b989c6bd.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.86141059.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.55190db5.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.ad9a3e11.js","assets/broker.1fe265d9.css","assets/DashPlayer.9f0060ed.js","assets/geometryUtils.886e3e6a.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.c4e04ddf.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),f(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",b),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.a67b0b74.js.map
