import"./outputWidgets.903ef13f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="e689d756-9ee5-4876-9a47-09574d7d7470",e._sentryDebugIdIdentifier="sentry-dbid-e689d756-9ee5-4876-9a47-09574d7d7470")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.08ed6687.js.map
