import{x as t,b as s,eu as o}from"./outputWidgets.903ef13f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="53311f1c-5181-4b35-b35c-32f53c49d54d",e._sentryDebugIdIdentifier="sentry-dbid-53311f1c-5181-4b35-b35c-32f53c49d54d")}catch{}})();const r={},c={class:"organization-settings"};function d(e,n){return s(),o("div",c,"Organization settings")}const f=t(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.a1a8f264.js.map
