import{cG as d}from"./outputWidgets.903ef13f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b7448fd9-a6a2-4779-92c4-bebf161adfca",e._sentryDebugIdIdentifier="sentry-dbid-b7448fd9-a6a2-4779-92c4-bebf161adfca")}catch{}})();const o=(e,r)=>{d.error({message:e,description:r})};export{o as p};
//# sourceMappingURL=popupNotifcation.aeec7ea3.js.map
