import"./outputWidgets.903ef13f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="e00c2369-4f58-477e-87bb-030f5f8c4788",e._sentryDebugIdIdentifier="sentry-dbid-e00c2369-4f58-477e-87bb-030f5f8c4788")}catch{}})();function c(e){return e.charAt(0).toUpperCase()+e.slice(1)}function a(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{c,a as n};
//# sourceMappingURL=string.82fbc777.js.map
