import{R as t}from"./Title.a0ce44ea.js";import{F as n}from"./outputWidgets.903ef13f.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="5976ad42-6bdd-44c4-89b7-db2306d5e4b0",d._sentryDebugIdIdentifier="sentry-dbid-5976ad42-6bdd-44c4-89b7-db2306d5e4b0")}catch{}})();const b=n(t);export{b as A};
//# sourceMappingURL=index.d93d8aa2.js.map
