import{v as a}from"./icons.c6b9d5b7.js";import{d as r,a as d,b as c,eu as i,f,u as _,aJ as l,x as u}from"./outputWidgets.903ef13f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="858d1e28-f11f-40ff-96e1-2e1d4d072633",e._sentryDebugIdIdentifier="sentry-dbid-858d1e28-f11f-40ff-96e1-2e1d4d072633")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=d("icon");return c(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[f(s,{class:"icon",path:_(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.62e2ea15.js.map
