import{S as p}from"./Sidebar.14903d99.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.876e0b87.js";import{G as l,H as d,I as f}from"./icons.c6b9d5b7.js";import{d as u,eA as b,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.903ef13f.js";import{a as w}from"./asyncComputed.c4e04ddf.js";import"./router.ddb32f08.js";import{O as z}from"./organization.3570e1df.js";import"./index.7a97ebf0.js";import{B as h}from"./BaseLayout.206b37c4.js";import"./Tooltip.9897857a.js";import"./logo.084e5d7c.js";import"./index.038e0c5b.js";import"./Title.a0ce44ea.js";import"./index.ff825c04.js";import"./index.33a83bfb.js";import"./index.e5fe38b8.js";import"./gateway.a6a9ad01.js";import"./activeRecord.55ed0790.js";import"./pubsub.c9a1cd12.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="fa2408da-28b2-4e1f-aaa1-40f6bf0ff37e",a._sentryDebugIdIdentifier="sentry-dbid-fa2408da-28b2-4e1f-aaa1-40f6bf0ff37e")}catch{}})();const q=u({__name:"Organization",setup(a){const n=b().params.organizationId,{result:o}=w(()=>z.get(n)),i=g(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:d,path:"members"},{name:"Billing",icon:f,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.9a00a551.js.map
