import{d as f,eA as u,J as b,b as y,c as g,u as _}from"./outputWidgets.903ef13f.js";import{a as w}from"./asyncComputed.c4e04ddf.js";import"./router.ddb32f08.js";import{M as n}from"./member.74ca7c87.js";import"./index.7a97ebf0.js";import{C as I}from"./CrudView.87fcb808.js";import"./Title.a0ce44ea.js";import"./index.e5fe38b8.js";import"./gateway.a6a9ad01.js";import"./activeRecord.55ed0790.js";import"./pubsub.c9a1cd12.js";import"./icons.c6b9d5b7.js";import"./index.038e0c5b.js";import"./Form.49dc913d.js";import"./url.08ed6687.js";import"./index.c70ecf50.js";import"./index.d93d8aa2.js";import"./index.abf1ee4c.js";import"./index.ff825c04.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="78628e99-21ee-466f-99f5-b54f484fed5e",e._sentryDebugIdIdentifier="sentry-dbid-78628e99-21ee-466f-99f5-b54f484fed5e")}catch{}})();const F=f({__name:"Members",setup(e){const r=u().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=b(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.5bef5d54.js.map
